From 64deac55639d3c22da9b91687294cfe452be21dd Mon Sep 17 00:00:00 2001
From: marko <Unknown>
Date: Thu, 6 Nov 2008 11:17:56 +0000
Subject: [PATCH] branches/innodb+: ibuf_get_volume_buffered(): Note that the
 volume includes only buffered inserts, not delete-marks or deletes. This is
 because ibuf_rec_get_volume() only returns nonzero for inserts.

---
 ibuf/ibuf0ibuf.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/ibuf/ibuf0ibuf.c b/ibuf/ibuf0ibuf.c
index 15bf777407..cbfe7a5894 100644
--- a/ibuf/ibuf0ibuf.c
+++ b/ibuf/ibuf0ibuf.c
@@ -2527,8 +2527,8 @@ ibuf_contract_after_insert(
 }
 
 /*************************************************************************
-Gets an upper limit for the combined size of entries buffered in the insert
-buffer for a given page. */
+Gets an upper limit for the combined size of inserts buffered for a
+given page. */
 static
 ulint
 ibuf_get_volume_buffered(
@@ -2560,7 +2560,7 @@ ibuf_get_volume_buffered(
 	ut_ad((pcur->latch_mode == BTR_MODIFY_PREV)
 	      || (pcur->latch_mode == BTR_MODIFY_TREE));
 
 	/* Count the volume of records earlier in the alphabetical order than
 	pcur */
 
 	volume = 0;
@@ -2560,7 +2560,7 @@ ibuf_get_volume_buffered(
 	      || (pcur->latch_mode == BTR_MODIFY_TREE));
 
-	/* Count the volume of records earlier in the alphabetical order than
+	/* Count the volume of inserts earlier in the alphabetical order than
 	pcur */
 
-- 
2.30.9